/**
 *
 * This is for creating the comment at the top of generated files with the generated at date.
 * It will use the custom file header if defined on the configuration, or use the
 * default file header.
 * @memberof module:formatHelpers
 * @name fileHeader
 * @param {Object} options
 * @param {File} [options.file] - The file object that is passed to the formatter.
 * @param {'short' | 'xml' | 'long'} [options.commentStyle] - The only options are 'short', 'xml' and 'long', which will use the // or \<!-- --> or \/\* style comments respectively. Default fallback is 'long'.
 * @param {Formatting} [options.formatting] - Custom formatting properties that define parts of a comment in code. The configurable strings are: prefix, lineSeparator, header, and footer.
 * @returns {Promise<string>}
 * @example
 * ```js
 * StyleDictionary.registerFormat({
 *   name: 'myCustomFormat',
 *   formatter: function({ dictionary, file }) {
 *     return fileHeader({file, commentStyle: 'short'}) +
 *       dictionary.allTokens.map(token => `${token.name} = ${token.value}`)
 *         .join('\n');
 *   }
 * });
 * ```
 */
export default function fileHeader({ file, commentStyle, formatting }: {
    file?: import("../../../types/File.d.ts").File | undefined;
    commentStyle?: "long" | "short" | "xml" | undefined;
    formatting?: import("../../../types/File.d.ts").FormattingOptions | undefined;
}): Promise<string>;
export type File = import('../../../types/File.d.ts').File;
export type FileHeader = import('../../../types/File.d.ts').FileHeader;
export type Formatting = import('../../../types/File.d.ts').FormattingOptions;
