/**
 * @typedef {import('../../../../types/DesignToken.d.ts').DesignTokens} DesignTokens
 * @typedef {import('../../../../types/DesignToken.d.ts').Dictionary} Dictionary
 * @typedef {import('../../../../types/File.d.ts').File} File
 * @typedef {import('../../../../types/Config.d.ts').Config} Config
 * @typedef {import('../../../../types/Config.d.ts').LocalOptions} LocalOptions
 */

/**
 *
 * @param {DesignTokens} obj
 * @param {Config & LocalOptions} options
 * @param {number} depth
 */
function processJsonNode(obj, options, depth = 0) {
  let output = '';
  if (obj === null) {
    output += `''`;
  } else if (typeof obj === 'string') {
    output += `'${obj}'`;
  } else if (Object.hasOwn(obj, `${options.usesDtcg ? '$' : ''}value`)) {
    // if we have found a leaf (a property with a value) append the value
    output += `$${obj.name}`;
  } else {
    // if we have found a group of tokens, use the Sass group "(...)" syntax and loop -recursively- on the children
    output += '(\n';
    output += Object.keys(obj)
      .map(function (newKey) {
        const newProp = obj[newKey];
        const indent = '  '.repeat(depth + 1);
        return `${indent}'${newKey}': ${processJsonNode(newProp, options, depth + 1)}`;
      })
      .join(',\n');
    output += '\n' + '  '.repeat(depth) + ')';
  }
  return output;
}

/**
 * @param {{
 *   dictionary: Dictionary
 *   file: File & { mapName?: string }
 *   options: Config & LocalOptions
 * }} opts
 */
export default ({ dictionary, file, options }) => `
$${file.mapName ?? 'tokens'}: ${processJsonNode(dictionary.tokens, options)};
`;
